@@ -10,7 +10,7 @@ use Perinci::Object 'envresmulti';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-08-11'; # DATE
 our $DIST = 'App-GoogleSearchUtils'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %SPEC;
 
@@ -32,11 +32,14 @@ _
         queries => {
             'x.name.is_plural' => 1,
             'x.name.singular' => 'query',
-            schema => ['array*', of=>'str*'],
-            req => 1,
+            schema => ['array*', of=>'str*', min_len=>1],
             pos => 0,
             slurpy => 1,
         },
+        queries_from => {
+            summary => 'Supply queries from lines of text file (specify "-" for stdin)',
+            schema => 'filename*',
+        },
         delay => {
             summary => 'Delay between opening each query',
             schema => 'duration*',
@@ -102,6 +105,7 @@ _
     args_rels => {
         choose_all => [qw/time_start time_end/],
         choose_one => [qw/time_start time_past/],
+        req_one => [qw/queries queries_from/],
     },
     examples => [
         {
@@ -118,6 +122,20 @@ _
             test => 0,
             'x.doc.show_result' => 0,
         },
+        {
+            summary => 'Open queries from each line of file, add delay 3s after each query (e.g. to avoid getting rate-limited by Google)',
+            src => '[[prog]] --queries-from phrases.txt --delay 3s',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+        {
+            summary => 'Open queries from each line of stdin',
+            src => 'prog-that-produces-lines-of-phrases | [[prog]] --queries-from -',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
         {
             summary => 'Use a custom browser',
             src => 'BROWSER=lynx [[prog]] "a query"',
@@ -176,10 +194,21 @@ sub google_search {
     my $action = $args{action} // 'web';
     my $type = $args{type} // 'web';
 
+    my @queries;
+    if (defined $args{queries_from}) {
+        require File::Slurper::Dash;
+        my $content = File::Slurper::Dash::read_text($args{queries_from});
+        @queries = map { chomp(my $line = $_); $line } split /^/m, $content;
+    } elsif ($args{queries} && @{ $args{queries} }) {
+        @queries = @{ $args{queries} };
+    } else {
+        return [400, "Please specify either queries or queries_from"];
+    }
+
     my @rows;
     my $envres = envresmulti();
     my $i = -1;
-    for my $query0 (@{ $args{queries} }) {
+    for my $query0 (@queries) {
         $i++;
         if ($i > 0 && $args{delay}) {
             log_trace "Sleeping %s second(s) ...", $args{delay};
@@ -275,7 +304,7 @@ App::GoogleSearchUtils - CLI utilites related to google searching
 
 =head1 VERSION
 
-This document describes version 0.009 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-08-11.
+This document describes version 0.010 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2022-08-11.
 
 =head1 SYNOPSIS
 
@@ -337,7 +366,11 @@ Number of results per page.
 
 String to add at the beginning of each query.
 
-=item * B<queries>* => I<array[str]>
+=item * B<queries> => I<array[str]>
+
+=item * B<queries_from> => I<filename>
+
+Supply queries from lines of text file (specify "-" for stdin).
 
 =item * B<time_end> => I<date>
 
